@@ -49,7 +49,6 @@ import javax.swing.Icon;
 import javax.swing.InputMap;
 import javax.swing.ListSelectionModel;
 import javax.swing.JButton;
-import javax.swing.JCheckBox;
 import javax.swing.JComboBox;
 import javax.swing.JComponent;
 import javax.swing.JFrame;
@@ -71,7 +70,6 @@ import javax.swing.Timer;
 import javax.swing.TransferHandler;
 import javax.swing.WindowConstants;
 import javax.swing.event.ChangeEvent;
-import javax.swing.event.ChangeListener;
 import javax.swing.event.ListDataEvent;
 import javax.swing.event.ListDataListener;
 import javax.swing.event.ListSelectionEvent;
@@ -99,6 +97,7 @@ import uk.ac.starlink.table.gui.TableLoadDialog;
 import uk.ac.starlink.table.gui.TableLoadWorker;
 import uk.ac.starlink.table.gui.TableLoader;
 import uk.ac.starlink.table.storage.MonitorStoragePolicy;
+import uk.ac.starlink.topcat.activate.ActivationWindow;
 import uk.ac.starlink.topcat.contrib.basti.BaSTITableLoadDialog;
 import uk.ac.starlink.topcat.contrib.gavo.GavoTableLoadDialog;
 import uk.ac.starlink.topcat.interop.PlasticCommunicator;
@@ -119,13 +118,8 @@ import uk.ac.starlink.topcat.plot.LinesWindow;
 import uk.ac.starlink.topcat.plot.PlotWindow;
 import uk.ac.starlink.topcat.plot.SphereWindow;
 import uk.ac.starlink.topcat.plot2.Control;
-import uk.ac.starlink.topcat.plot2.CubePlotWindow;
-import uk.ac.starlink.topcat.plot2.HistogramPlotWindow;
-import uk.ac.starlink.topcat.plot2.PlanePlotWindow;
-import uk.ac.starlink.topcat.plot2.SkyPlotWindow;
-import uk.ac.starlink.topcat.plot2.SpherePlotWindow;
+import uk.ac.starlink.topcat.plot2.PlotWindowType;
 import uk.ac.starlink.topcat.plot2.StackPlotWindow;
-import uk.ac.starlink.topcat.plot2.TimePlotWindow;
 import uk.ac.starlink.topcat.vizier.VizierTableLoadDialog;
 import uk.ac.starlink.util.DataSource;
 import uk.ac.starlink.util.Loader;
@@ -176,7 +170,7 @@ public class ControlWindow extends AuxWindow
     public static String TOPCAT_TOOLS_PROP = "topcat.exttools";
 
     private final JList tablesList_;
-    private final DefaultListModel tablesModel_;
+    private final TablesListModel tablesModel_;
     private final DefaultListModel loadingModel_;
     private final TableModelListener tableWatcher_ = this;
     private final TopcatListener topcatWatcher_ = this;
@@ -218,8 +212,7 @@ public class ControlWindow extends AuxWindow
     private final JComboBox subsetSelector_ = new JComboBox();
     private final JComboBox sortSelector_ = new JComboBox();
     private final JToggleButton sortSenseButton_ = new UpDownButton();
-    private final JButton activatorButton_ = new JButton();
-    private final JCheckBox rowSendButton_ = new JCheckBox();
+    private final JLabel activatorLabel_ = new JLabel();
     private final TopcatCommunicator communicator_;
 
     private final Action readAct_;
@@ -234,6 +227,7 @@ public class ControlWindow extends AuxWindow
     private final Action multisiaAct_;
     private final Action multissaAct_;
     private final Action cdsmatchAct_;
+    private final ModelViewAction datalinkAct_;
     private final Action logAct_;
     private final Action[] matchActs_;
     private final ShowAction[] showActs_;
@@ -254,7 +248,7 @@ public class ControlWindow extends AuxWindow
         taboutput_.setJDBCHandler( tabfact_.getJDBCHandler() );
 
         /* Set up a list of the known tables. */
-        tablesModel_ = new DefaultListModel();
+        tablesModel_ = new TablesListModel();
         loadingModel_ = new DefaultListModel();
         tablesList_ = new JList( tablesModel_ );
 
@@ -281,12 +275,7 @@ public class ControlWindow extends AuxWindow
                                                       sortSelector_ } );
         info.addGap();
         info.addLine( "Row Subset", subsetSelector_ );
-        info.addGap();
-        info.addLine( "Activation Action",
-                      new Component[] { activatorButton_, rowSendButton_ } );
-        activatorButton_.setText( "           " );
-        rowSendButton_.setText( "Broadcast Row" );
-        rowSendButton_.setEnabled( false );
+        info.addLine( "Activation Actions", activatorLabel_ );
         info.fillIn();
 
         /* Reduce size of unused control panel. */
@@ -334,18 +323,6 @@ public class ControlWindow extends AuxWindow
             if ( interopPanel != null ) {
                 infoPanel.add( interopPanel, BorderLayout.SOUTH );
             }
-            communicator_.addConnectionListener( new ChangeListener() {
-                public void stateChanged( ChangeEvent evt ) {
-                    rowSendButton_.setEnabled( getCurrentModel() != null 
-                                            && communicator_.isConnected() );
-                }
-            } );
-            rowSendButton_.setToolTipText( "On Row Activation send a "
-                                         +  communicator_.getProtocolName()
-                                         + " highlight row message"
-                                         + " to all registered applications" );
-            rowSendButton_.setEnabled( getCurrentModel() != null
-                                    && communicator_.isConnected() );
         }
 
         /* Set up actions. */
@@ -396,12 +373,12 @@ public class ControlWindow extends AuxWindow
                                "Launch Mirage to display the current table" );
         mirageAct_.setEnabled( MirageHandler.isMirageAvailable() );
 
-        final ModelViewAction viewerAct = 
+        final ModelViewAction viewerAct;
+        viewActs_ = new ModelViewAction[] {
+            viewerAct =
             new ModelViewWindowAction( "Table Data", ResourceIcon.VIEWER,
                                        "Display table cell data",
-                                       TableViewerWindow.class );
-        viewActs_ = new ModelViewAction[] {
-            viewerAct,
+                                       TableViewerWindow.class ),
             new ModelViewWindowAction( "Table Parameters", ResourceIcon.PARAMS,
                                        "Display table metadata",
                                        ParameterWindow.class ),
@@ -414,6 +391,14 @@ public class ControlWindow extends AuxWindow
             new ModelViewWindowAction( "Column Statistics", ResourceIcon.STATS,
                                        "Display statistics for each column",
                                        StatsWindow.class ),
+            new ActivationWindowAction( "Activation Actions",
+                                        ResourceIcon.ACTIVATE,
+                                        "Display actions invoked when rows "
+                                      + "are selected" ),
+            datalinkAct_ =
+            new ModelViewWindowAction( "DataLink View", ResourceIcon.DATALINK,
+                                       "Show row data as a DataLink table",
+                                       DatalinkWindow.class ),
         };
         graphicsActs_ = new Action[] {
             new GraphicsWindowAction( "Histogram Plot (old)",
@@ -438,35 +423,14 @@ public class ControlWindow extends AuxWindow
                                       DensityWindow.class ),
         };
         Action[] plot2Acts = new Action[] {
-            new Plot2WindowAction( "Histogram Plot",
-                                   ResourceIcon.PLOT2_HISTOGRAM,
-                                   "Plane plotting window configured for "
-                                   + "convenience for histogram plotting",
-                                   HistogramPlotWindow.class ),
-            new Plot2WindowAction( "Plane Plot",
-                                   ResourceIcon.PLOT2_PLANE,
-                                   "Plane plotting window",
-                                   PlanePlotWindow.class ),
-            new Plot2WindowAction( "Sky Plot",
-                                   ResourceIcon.PLOT2_SKY,
-                                   "Sky plotting window",
-                                   SkyPlotWindow.class ),
-            new Plot2WindowAction( "Cube Plot",
-                                   ResourceIcon.PLOT2_CUBE,
-                                   "3D plotting window"
-                                   + " using Cartesian coordinates",
-                                   CubePlotWindow.class ),
-            new Plot2WindowAction( "Sphere Plot",
-                                   ResourceIcon.PLOT2_SPHERE,
-                                   "3D plotting window"
-                                   + " using spherical polar coordinates",
-                                   SpherePlotWindow.class ),
+            new Plot2WindowAction( PlotWindowType.HISTOGRAM ),
+            new Plot2WindowAction( PlotWindowType.PLANE ),
+            new Plot2WindowAction( PlotWindowType.SKY ),
+            new Plot2WindowAction( PlotWindowType.CUBE ),
+            new Plot2WindowAction( PlotWindowType.SPHERE ),
         };
         Action[] morePlot2Acts = new Action[] {
-            new Plot2WindowAction( "Time Plot",
-                                   ResourceIcon.PLOT2_TIME,
-                                   "Time series plotting window",
-                                   TimePlotWindow.class ),
+            new Plot2WindowAction( PlotWindowType.TIME ),
         };
 
         matchActs_ = new Action[] {
@@ -581,8 +545,10 @@ public class ControlWindow extends AuxWindow
         toolBar.addSeparator();
 
         /* Add table view buttons to the toolbar. */
-        for ( int i = 0; i < viewActs_.length; i++ ) {
-            toolBar.add( viewActs_[ i ] );
+        for ( Action viewAct : viewActs_ ) {
+            if ( viewAct != datalinkAct_ ) {
+                toolBar.add( viewAct );
+            }
         }
         toolBar.addSeparator();
 
@@ -1005,7 +971,7 @@ public class ControlWindow extends AuxWindow
      *
      * @return  list model of {@link TopcatModel} objects
      */
-    public ListModel getTablesListModel() {
+    public TypedListModel<TopcatModel> getTablesListModel() {
         return tablesModel_;
     }
 
@@ -1287,7 +1253,6 @@ public class ControlWindow extends AuxWindow
             int visRows = viewModel.getRowCount();
             String loc = tcModel.getLocation();
             String name = dataModel.getName();
-            Activator activator = tcModel.getActivator();
 
             idField_.setText( tcModel.getLabel() );
             indexLabel_.setText( tcModel.getID() + ": " );
@@ -1306,9 +1271,8 @@ public class ControlWindow extends AuxWindow
             sortSelector_.setModel( tcModel.getSortSelectionModel() );
             subsetSelector_.setModel( tcModel.getSubsetSelectionModel() );
             sortSenseButton_.setModel( tcModel.getSortSenseModel() );
-            activatorButton_.setAction( tcModel.getActivationAction() );
-            activatorButton_.setText( activator.toString() );
-            rowSendButton_.setModel( tcModel.getRowSendModel() );
+            activatorLabel_.setText( tcModel.getActivationWindow()
+                                            .getActivationSummary() );
         }
         else {
             idField_.setText( null );
@@ -1321,11 +1285,8 @@ public class ControlWindow extends AuxWindow
             sortSelector_.setModel( dummyComboBoxModel_ );
             subsetSelector_.setModel( dummyComboBoxModel_ );
             sortSenseButton_.setModel( dummyButtonModel_ );
-            activatorButton_.setModel( dummyButtonModel_ );
-            rowSendButton_.setModel( dummyButtonModel_ );
+            activatorLabel_.setText( null );
         }
-        rowSendButton_.setEnabled( communicator_ != null &&
-                                   communicator_.isConnected() );
 
         /* Make sure that the actions which relate to a particular table model
          * are up to date. */
@@ -1348,6 +1309,8 @@ public class ControlWindow extends AuxWindow
         for ( int i = 0; i < viewActs_.length; i++ ) {
             viewActs_[ i ].setEnabled( hasModel );
         }
+        datalinkAct_.setEnabled( hasModel &&
+                                 DatalinkWindow.isUseful( tcModel ) );
         for ( int i = 0; i < showActs_.length; i++ ) {
             ShowAction sact = showActs_[ i ];
             if ( sact.selEffect != sact.otherEffect ) {
@@ -1433,9 +1396,15 @@ public class ControlWindow extends AuxWindow
                 }
                 break;
 
-            /* Activator has changed. */
+            /* Activation actions have changed. */
             case TopcatEvent.ACTIVATOR:
-                updateInfo();
+                if ( evt.getModel() == getCurrentModel() ) {
+                    String actTxt = evt.getDatum() instanceof String
+                                  ? (String) evt.getDatum()
+                                  : evt.getModel().getActivationWindow()
+                                                  .getActivationSummary();
+                    activatorLabel_.setText( actTxt );
+                }
                 break;
         }
     }
@@ -1615,37 +1584,7 @@ public class ControlWindow extends AuxWindow
     /**
      * Class for showing a certain kind of window which applies to TopcatModels.
      */
-    private abstract class ModelViewAction extends BasicAction {
-
-        private final Map modelWindows_ = new WeakHashMap();
-
-        /**
-         * Constructor. 
-         *
-         * @param   name  action name
-         * @param   icon  action icon
-         * @param   shortdesc  action short description
-         */
-        ModelViewAction( String name, Icon icon, String shortdesc ) {
-            super( name, icon, shortdesc );
-        }
-
-        /**
-         * Displays this action's window type for the currently selected
-         * table.
-         */
-        public void actionPerformed( ActionEvent evt ) {
-            TopcatModel tcModel = getCurrentModel();
-            if ( tcModel == null ) {
-                return;
-            }
-            Window window = (Window) modelWindows_.get( tcModel );
-            if ( window == null ) {
-                window = createWindow( tcModel );
-                modelWindows_.put( tcModel, window );
-            }
-            window.setVisible( true );
-        }
+    private interface ModelViewAction extends Action {
 
         /**
          * Ensures that this action's window for a given table is visible
@@ -1655,33 +1594,18 @@ public class ControlWindow extends AuxWindow
          * @param  tcModel  table to reveal for
          * @param  visible  true to reveal, false to hide
          */
-        public void setViewVisible( TopcatModel tcModel, boolean visible ) {
-            Window window = (Window) modelWindows_.get( tcModel );
-            if ( window != null ) {
-                if ( visible ) {
-                    window.setVisible( true );
-                }
-                else {
-                    window.dispose();
-                }
-            }
-        }
-
-        /**
-         * Creates this action's window for a given table.
-         *
-         * @param  tcModel  table the window will apply to
-         */
-        protected abstract Window createWindow( TopcatModel tcModel );
+        void setViewVisible( TopcatModel tcModel, boolean visible );
     }
 
     /**
      * ModelViewAction class for actions which pop up a view window.
      */
-    private class ModelViewWindowAction extends ModelViewAction {
+    private class ModelViewWindowAction extends BasicAction
+                                        implements ModelViewAction {
 
         AuxWindow window_;
         final Constructor constructor_;
+        private final Map modelWindows_ = new WeakHashMap();
 
         /**
          * Constructor.
@@ -1710,7 +1634,41 @@ public class ControlWindow extends AuxWindow
             }
         }
 
-        protected Window createWindow( TopcatModel tcModel ) {
+        /**
+         * Displays this action's window type for the currently selected
+         * table.
+         */
+        public void actionPerformed( ActionEvent evt ) {
+            TopcatModel tcModel = getCurrentModel();
+            if ( tcModel == null ) {
+                return;
+            }
+            Window window = (Window) modelWindows_.get( tcModel );
+            if ( window == null ) {
+                window = createWindow( tcModel );
+                modelWindows_.put( tcModel, window );
+            }
+            window.setVisible( true );
+        }
+
+        public void setViewVisible( TopcatModel tcModel, boolean visible ) {
+            Window window = (Window) modelWindows_.get( tcModel );
+            if ( window != null ) {
+                if ( visible ) {
+                    window.setVisible( true );
+                }
+                else {
+                    window.dispose();
+                }
+            }
+        }
+
+        /**
+         * Creates this action's window for a given table.
+         *
+         * @param  tcModel  table the window will apply to
+         */
+        private Window createWindow( TopcatModel tcModel ) {
             try {
                 Object[] args = new Object[] { tcModel, ControlWindow.this };
                 try {
@@ -1732,6 +1690,33 @@ public class ControlWindow extends AuxWindow
         }
     }
 
+    /**
+     * Action for opening the Activation window.
+     */
+    private class ActivationWindowAction extends BasicAction
+                                         implements ModelViewAction {
+        ActivationWindowAction( String name, Icon icon, String shortdesc ) {
+            super( name, icon, shortdesc );
+        }
+        public void actionPerformed( ActionEvent evt ) {
+            TopcatModel tcModel = getCurrentModel();
+            if ( tcModel != null ) {
+                tcModel.getActivationWindow().setVisible( true );
+            }
+        }
+        public void setViewVisible( TopcatModel tcModel, boolean visible ) {
+            Window window = tcModel.getActivationWindow();
+            if ( window != null ) {
+                if ( visible ) {
+                    window.setVisible( true );
+                }
+                else {
+                    window.dispose();
+                }
+            }
+        }
+    }
+
     /**
      * Action class for old-style graphics windows.
      */
@@ -1773,26 +1758,25 @@ public class ControlWindow extends AuxWindow
     /**
      * Action class for new-style graphics windows.
      */
-    private class Plot2WindowAction
-            extends TopcatWindowAction<StackPlotWindow> {
+    private class Plot2WindowAction extends BasicAction
+                                    implements TopcatToolAction {
+        private final PlotWindowType ptype_;
+        private Component plot2parent_;
 
         /**
          * Constructor.
          *
-         * @param  name  action name
-         * @param  icon  action icon
-         * @param  shortdesc  action short description
-         * @param  winClass  StackPlotWindow subclass - must have a
-         *         constructor that takes (Component)
+         * @param  ptype  plot type
          */
-        Plot2WindowAction( String name, Icon icon, String shortdesc,
-                           Class<? extends StackPlotWindow> winClazz ) {
-            super( name, icon, shortdesc, winClazz );
+        Plot2WindowAction( PlotWindowType ptype ) {
+            super( ptype.getName() + " Plot", ptype.getIcon(),
+                   ptype.getDescription() );
+            ptype_ = ptype;
         }
 
-        @Override
         public void actionPerformed( ActionEvent evt ) {
-            StackPlotWindow window = createWindow();
+            StackPlotWindow window =
+                ptype_.createWindow( plot2parent_, tablesModel_ );
             TopcatModel tcModel = getCurrentModel();
             Control dfltControl =
                 window.getControlManager().createDefaultControl( tcModel );
@@ -1801,6 +1785,10 @@ public class ControlWindow extends AuxWindow
             }
             window.setVisible( true );
         }
+
+        public void setParent( Component parent ) {
+            plot2parent_ = parent;
+        }
     }
 
     /**
@@ -2220,4 +2208,15 @@ public class ControlWindow extends AuxWindow
         }
     }
 
+    /**
+     * ListModel for holding TopcatModels.
+     */
+    private static class TablesListModel
+                         extends DefaultListModel
+                         implements TypedListModel<TopcatModel> {
+        @Override
+        public TopcatModel getElementAt( int index ) {
+             return (TopcatModel) super.getElementAt( index );
+        }
+    }
 }
