@@ -132,7 +132,7 @@ public class ResourceIcon implements Icon {
         PARAMS = makeIcon( "tablemeta0.png" ),
         VIEWER = makeIcon( "browser1.png" ),
         SUBSETS = makeIcon( "venn2.png" ),
-        FUNCTION = makeIcon( "fx2.png" ),
+        FUNCTION = makeIcon( "fx4.png" ),
         MATCH1 = makeIcon( "matchOne2.png" ),
         MATCH2 = makeIcon( "matchTwo2.png" ),
         MATCHN = makeIcon( "matchN.png" ),
@@ -140,12 +140,20 @@ public class ResourceIcon implements Icon {
         MULTICONE = makeIcon( "cones.png" ),
         MULTISIA = makeIcon( "sias.png" ),
         MULTISSA = makeIcon( "ssas.png" ),
+        DATALINK = makeIcon( "datalink2.png" ),
         SAMP = makeIcon( "comms2.png" ),
         GAVO = makeIcon( "virgo3.png" ),
         VIZIER = makeIcon( "vizmini.png" ),
         BASTI = makeIcon( "BaSTI_icon_B.png" ),
         TREE_DIALOG = makeIcon( "browse.png" ),
         CLASSIFY = makeIcon( "classify3.png" ),
+        ACTIVATE = makeIcon( "activate3.png" ),
+        REACTIVATE = makeIcon( "flash-1.png" ),
+        REACTIVATE_ALL = makeIcon( "flash-2d.png" ),
+        ACTIVATE_SEQ = makeIcon( "flash1seq.png" ),
+        ACTIVATE_SEQ_ALL = makeIcon( "flash2seq.png" ),
+        CANCEL_SEQ = makeIcon( "noseq.png" ),
+        DELETE_INACTIVE = makeIcon( "trash2-box.png" ),
 
         /* Specific actions. */
         UNSORT = makeIcon( "arrow_level.png" ),
@@ -731,6 +739,10 @@ public class ResourceIcon implements Icon {
                          toSaveIcon( TTRI.FORM_SKYDENSITY ) );
         putMap( nameMap, "IMPORT_FORM_SKYDENSITY",
                          toImportIcon( TTRI.FORM_SKYDENSITY ) );
+        putMap( nameMap, "SAVE_FORM_HISTOGRAM",
+                         toSaveIcon( TTRI.FORM_HISTOGRAM ) );
+        putMap( nameMap, "IMPORT_FORM_HISTOGRAM",
+                         toImportIcon( TTRI.FORM_HISTOGRAM ) );
 
         return nameMap;
     }
