@@ -1,5 +1,6 @@
 package uk.ac.starlink.topcat.join;
 
+import java.awt.BorderLayout;
 import java.awt.Component;
 import java.io.IOException;
 import java.net.URL;
@@ -61,7 +62,8 @@ public class InterMatchSpec extends MatchSpec {
         this.engine = engine;
 
         Box main = Box.createVerticalBox();
-        add( main );
+        setLayout( new BorderLayout() );
+        add( main, BorderLayout.NORTH );
 
         /* Set up table/column selector panels. */
         tupleSelectors = new TupleSelector[ nTable ];
