@@ -27,6 +27,7 @@ import uk.ac.starlink.topcat.BasicAction;
 import uk.ac.starlink.topcat.ResourceIcon;
 import uk.ac.starlink.topcat.RowSubset;
 import uk.ac.starlink.topcat.TopcatModel;
+import uk.ac.starlink.topcat.TypedListModel;
 import uk.ac.starlink.ttools.plot.Range;
 import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.PlotLayer;
@@ -37,7 +38,6 @@ import uk.ac.starlink.ttools.plot2.ReportMap;
 import uk.ac.starlink.ttools.plot2.SingleGanger;
 import uk.ac.starlink.ttools.plot2.Surface;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
-import uk.ac.starlink.ttools.plot2.config.StyleKeys;
 import uk.ac.starlink.ttools.plot2.data.FloatingCoord;
 import uk.ac.starlink.ttools.plot2.geom.PlaneAspect;
 import uk.ac.starlink.ttools.plot2.geom.PlaneDataGeom;
@@ -46,6 +46,7 @@ import uk.ac.starlink.ttools.plot2.geom.PlaneSurface;
 import uk.ac.starlink.ttools.plot2.geom.PlaneSurfaceFactory;
 import uk.ac.starlink.ttools.plot2.layer.AbstractKernelDensityPlotter;
 import uk.ac.starlink.ttools.plot2.layer.BinBag;
+import uk.ac.starlink.ttools.plot2.layer.Combiner;
 import uk.ac.starlink.ttools.plot2.layer.DensogramPlotter;
 import uk.ac.starlink.ttools.plot2.layer.FixedKernelDensityPlotter;
 import uk.ac.starlink.ttools.plot2.layer.FunctionPlotter;
@@ -53,6 +54,7 @@ import uk.ac.starlink.ttools.plot2.layer.HistogramPlotter;
 import uk.ac.starlink.ttools.plot2.layer.KnnKernelDensityPlotter;
 import uk.ac.starlink.ttools.plot2.layer.Normalisation;
 import uk.ac.starlink.ttools.plot2.layer.Stats1Plotter;
+import uk.ac.starlink.ttools.plot2.layer.Unit;
 
 /**
  * Layer plot window for histograms.
@@ -77,9 +79,11 @@ public class HistogramPlotWindow
      * Constructor.
      *
      * @param  parent  parent component
+     * @param  tablesModel  list of available tables
      */
-    public HistogramPlotWindow( Component parent ) {
-        super( "Histogram Plot", parent, PLOT_TYPE, PLOT_GUI );
+    public HistogramPlotWindow( Component parent,
+                                TypedListModel<TopcatModel> tablesModel ) {
+        super( "Histogram Plot", parent, PLOT_TYPE, PLOT_GUI, tablesModel );
 
         /* This window currently works with a single plot zone, with index zero.
          * At least, the histogram-specific behaviour applies only
@@ -160,6 +164,7 @@ public class HistogramPlotWindow
      * @return   table representing the current histogram
      */
     private StarTable getBinDataTable( int iz ) {
+        Unit unit = Unit.UNIT;
         PlotPanel plotPanel = getPlotPanel();
         if ( iz >= plotPanel.getZoneCount() ) {
             return null;
@@ -250,6 +255,7 @@ public class HistogramPlotWindow
             GuiDataSpec dataSpec = (GuiDataSpec) layer.getDataSpec();
             boolean isCumulative = style.isCumulative();
             Normalisation norm = style.getNormalisation();
+            Combiner combiner = style.getCombiner();
             int icWeight = plotter.getWeightCoordIndex();
             boolean hasWeight =
                 icWeight >= 0 && ! dataSpec.isCoordBlank( icWeight );
@@ -273,7 +279,8 @@ public class HistogramPlotWindow
                     .append( "_" );
             }
             if ( hasWeight ) {
-                nbuf.append( "SUM_" )
+                nbuf.append( combiner.getName() )
+                    .append( "_" )
                     .append( weightName );
             }
             else {
@@ -289,7 +296,12 @@ public class HistogramPlotWindow
             if ( isCumulative ) {
                 descripWords.add( "cumulative" );
             }
-            descripWords.add( "count" );
+            if ( hasWeight ) {
+                descripWords.add( combiner.getName().toLowerCase() );
+            }
+            else {
+                descripWords.add( "count" );
+            }
             StringBuffer dbuf = new StringBuffer();
             for ( String word : descripWords ) {
                 dbuf.append( word )
@@ -315,7 +327,7 @@ public class HistogramPlotWindow
             final Number[] data = new Number[ nrow ];
             final Class clazz = isInt ? Integer.class : Double.class;
             for ( Iterator<BinBag.Bin> binIt =
-                      binBag.binIterator( isCumulative, norm );
+                      binBag.binIterator( isCumulative, norm, unit );
                   binIt.hasNext(); ) {
                 BinBag.Bin bin = binIt.next();
                 Double xmin = new Double( bin.getXMin() );
@@ -448,13 +460,13 @@ public class HistogramPlotWindow
      */
     private static Plotter[] createHistogramPlotters() {
         FloatingCoord xCoord = PlaneDataGeom.X_COORD;
-        ConfigKey<Normalisation> normKey = StyleKeys.NORMALISE;
+        ConfigKey<Unit> unitKey = null;
         return new Plotter[] {
-            new HistogramPlotter( xCoord, true, normKey ),
-            new FixedKernelDensityPlotter( xCoord, true, normKey ),
-            new KnnKernelDensityPlotter( xCoord, true, normKey ),
+            new HistogramPlotter( xCoord, true, null ),
+            new FixedKernelDensityPlotter( xCoord, true, null ),
+            new KnnKernelDensityPlotter( xCoord, true, null ),
             new DensogramPlotter( xCoord, true ),
-            new Stats1Plotter( xCoord, true, normKey ),
+            new Stats1Plotter( xCoord, true, null ),
             FunctionPlotter.PLANE,
         };
     }
