@@ -1,6 +1,8 @@
 package uk.ac.starlink.topcat.plot2;
 
 import java.awt.Component;
+import uk.ac.starlink.topcat.TopcatModel;
+import uk.ac.starlink.topcat.TypedListModel;
 import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.SingleGanger;
 import uk.ac.starlink.ttools.plot2.PlotType;
@@ -23,9 +25,11 @@ public class PlanePlotWindow
      * Constructor.
      *
      * @param  parent  parent component
+     * @param  tablesModel  list of available tables
      */
-    public PlanePlotWindow( Component parent ) {
-        super( "Plane Plot", parent, PLOT_TYPE, PLOT_GUI );
+    public PlanePlotWindow( Component parent,
+                            TypedListModel<TopcatModel> tablesModel ) {
+        super( "Plane Plot", parent, PLOT_TYPE, PLOT_GUI, tablesModel );
         getToolBar().addSeparator();
         addHelp( "PlanePlotWindow" );
     }
